#==========================================================================================================================================
# Repository path:    $HeadURL: https://90.145.156.222/DMS-Houtribdijk/code/nc-checks/src/checks/checkDMS_difs.py $
# Last committed:     $Revision: 539724 $ 
#                     $Author: jansink $
#                     $Date: 2020-02-18 13:48:17 +0100 (di, 18 feb 2020) $
#
# Copyright © 2019, ®HKV services, All Rights Reserved.
#==========================================================================================================================================
import pandas as pd
import datetime
from .checkParameterDifs import checkParameterDifs


def checkDMS_difs(logger, thredds_data, filename):

    df = pd.DataFrame(columns=['Opwerking', 'Instrument', 'Location1',
                               'Location2', 'Parameter', 'Date', 'Nc1', 'Nc2', 'inRange', 'errStr'])

    checklist = pd.read_csv(filename, skiprows=0, sep=";", header=0)

    enddate = pd.to_datetime(pd.datetime.now().strftime('%Y-%m-%d'))

    for i in range(len(checklist)):

        opwerking = checklist['Opwerking'][i]
        inst = checklist['Instrument'][i]
        loc1 = checklist['Location1'][i]
        loc2 = checklist['Location2'][i]
        parName = checklist['Parameter'][i]

        begindays = int(checklist['Begintime'][i])
        t1 = enddate + pd.to_timedelta(begindays, unit='d')
        enddays = int(checklist['Endtime'][i])
        t2 = enddate + pd.to_timedelta(enddays, unit='d')

        t = t1
        dt = checklist['Timestep'][i]

        lowerLimit = checklist['Lower'][i]
        upperLimit = checklist['Upper'][i]
        errorValue = checklist['Errorvalue'][i]
        ignoreNaN = checklist['IgnoreNaN'][i]

        while 1:

            if t >= t2:
                break
            datestr = '{0:04}'.format(t.year) + '{0:02}'.format(t.month) + \
                '{0:02}'.format(t.day) + '{0:02}'.format(t.hour) + '0000'
            nc_f1 = thredds_data + opwerking + '/'+inst+'/' + \
                loc1 + '/'+inst+'_' + loc1 + '_' + datestr + '.nc'
            nc_f2 = thredds_data + opwerking + '/'+inst+'/' + \
                loc2 + '/'+inst+'_' + loc2 + '_' + datestr + '.nc'

            inRange, errStr = checkParameterDifs(nc_f1, nc_f2, parName, lowerLimit, upperLimit, errorValue, ignoreNaN)

            logger.info(opwerking+';'+inst+';'+loc1+';'+loc2+';' +
                        parName+';'+nc_f1+';'+nc_f2+';'+str(inRange)+';'+errStr+'\n')

            row = [opwerking, inst, loc1, loc2, parName, datestr,
                   nc_f1, nc_f2, str(inRange), errStr]
            df.loc[len(df)] = row

            t = t+datetime.timedelta(hours=int(dt))

    return df
